import { createCommand } from "../../../types.js";
import { createNamespaceSubcommand } from "./create-namespace.js";
import { deleteSubcommand } from "./delete.js";
import { deleteNamespaceSubcommand } from "./delete-namespace.js";
import { getSubcommand } from "./get.js";
import { keysSubcommand } from "./keys.js";
import { listNamespacesSubcommand } from "./list-namespaces.js";
import { replSubcommand } from "./repl.js";
import { searchSubcommand } from "./search.js";
import { setSubcommand } from "./set.js";
import { statsSubcommand } from "./stats.js";
import { getCommand } from "../../../command-prefix.js";
export const command = createCommand({
    name: 'keyvalue',
    aliases: ['kv', 'keyvalues'],
    description: 'Manage keyvalue storage for your projects',
    tags: ['read-only', 'fast', 'requires-auth'],
    examples: [
        {
            command: getCommand('cloud keyvalue repl'),
            description: 'Start interactive key-value REPL',
        },
        { command: getCommand('cloud kv get mykey'), description: 'Get value for key' },
    ],
    subcommands: [
        replSubcommand,
        getSubcommand,
        setSubcommand,
        deleteSubcommand,
        statsSubcommand,
        searchSubcommand,
        keysSubcommand,
        listNamespacesSubcommand,
        createNamespaceSubcommand,
        deleteNamespaceSubcommand,
    ],
    requires: { auth: true },
});
export default command;
//# sourceMappingURL=index.js.map