export declare const embeddingsSubcommand: import("../../../types.ts").CommandDefinition;
export declare const imageSubcommand: import("../../../types.ts").CommandDefinition;
export declare const speechSubcommand: import("../../../types.ts").CommandDefinition;
export declare const transcriptionSubcommand: import("../../../types.ts").CommandDefinition;
export declare const videoSubcommand: import("../../../types.ts").CommandDefinition;
//# sourceMappingURL=modalities.d.ts.map