import { type Logger, WorkflowService } from '@agentuity/core';
import type { AuthData, Config, GlobalOptions } from '../../../types.ts';
export interface WorkflowContext {
    logger: Logger;
    auth: AuthData;
    config: Config | null;
    options: GlobalOptions;
}
export declare function createWorkflowAdapter(ctx: WorkflowContext): Promise<WorkflowService>;
//# sourceMappingURL=util.d.ts.map