import type { Logger } from '@agentuity/core';
import { AIGatewayService } from '@agentuity/aigateway';
import type { AuthData, Config, GlobalOptions, ProjectConfig } from '../../../types.ts';
export declare function getAIGatewayUrl(region?: string, overrides?: {
    aigateway_url?: string;
} | null): string;
export declare function createAIGatewayService(ctx: {
    logger: Logger;
    auth: AuthData;
    region?: string;
    project?: ProjectConfig;
    config: Config | null;
    options: GlobalOptions;
}): AIGatewayService;
export declare function createPublicAIGatewayService(ctx: {
    logger: Logger;
    region?: string;
    config: Config | null;
}): AIGatewayService;
export declare function getCompletionText(response: unknown): string;
//# sourceMappingURL=util.d.ts.map