import { createCommand } from "../../types.js";
import capabilitiesCommand from "./capabilities/index.js";
import promptCommand from "./prompt/index.js";
import schemaCommand from "./schema/index.js";
import opencodeCommand from "./opencode/index.js";
import claudeCodeCommand from "./claude-code/index.js";
import introSubcommand from "./intro.js";
import detectSubcommand from "./detect.js";
import { getCommand } from "../../command-prefix.js";
export const command = createCommand({
    name: 'ai',
    description: 'AI coding agent related commands',
    skipUpgradeCheck: true,
    tags: ['fast'],
    examples: [
        {
            command: getCommand('ai detect'),
            description: 'Detect if running from an AI coding agent',
        },
        {
            command: getCommand('ai intro'),
            description: 'Introduce the Agentuity CLI to your AI agent',
        },
        {
            command: getCommand('ai opencode install'),
            description: 'Install Agentuity Open Code plugin',
        },
        {
            command: getCommand('ai claude-code install'),
            description: 'Install Agentuity Coder plugin for Claude Code',
        },
        {
            command: getCommand('ai capabilities show'),
            description: 'Show CLI capabilities for AI agents',
        },
        {
            command: getCommand('ai schema show'),
            description: 'Output CLI schema for AI consumption',
        },
    ],
    subcommands: [
        detectSubcommand,
        introSubcommand,
        opencodeCommand,
        claudeCodeCommand,
        capabilitiesCommand,
        promptCommand,
        schemaCommand,
    ],
});
//# sourceMappingURL=index.js.map