import { createCommand } from "../../../types.js";
import show from "./show.js";
import path from "./path.js";
export default createCommand({
    name: 'logs',
    description: 'View and manage CLI execution logs',
    subcommands: [show, path],
});
//# sourceMappingURL=index.js.map