import { createCommand } from "../../types.js";
import logs from "./logs/index.js";
import report from "./report.js";
import system from "./system.js";
export const command = createCommand({
    name: 'support',
    description: 'Create support tickets and report issues',
    skipInternalLogging: true,
    subcommands: [logs, report, system],
});
//# sourceMappingURL=index.js.map