import { createCommand } from "../../../types.js";
import { addSubcommand } from "./add.js";
import { listSubcommand } from "./list.js";
import { removeSubcommand } from "./remove.js";
export const accountCommand = createCommand({
    name: 'account',
    description: 'Manage GitHub App installations',
    subcommands: [addSubcommand, listSubcommand, removeSubcommand],
});
//# sourceMappingURL=index.js.map