import { createCommand } from "../../../types.js";
import { listCommand } from "./list.js";
import { addCommand } from "./add.js";
import { deleteCommand } from "./delete.js";
import { getCommand } from "../../../command-prefix.js";
export const sshSubcommand = createCommand({
    name: 'ssh',
    description: 'Manage SSH keys',
    tags: ['fast', 'requires-auth'],
    examples: [
        { command: getCommand('auth ssh list'), description: 'List all SSH keys' },
        { command: getCommand('auth ssh add'), description: 'Add a new SSH key' },
    ],
    subcommands: [listCommand, addCommand, deleteCommand],
});
//# sourceMappingURL=index.js.map