import { createCommand } from "../../../types.js";
import { listSubcommand } from "./list.js";
import { createSubcommand } from "./create.js";
import { getSubcommand } from "./get.js";
import { deleteSubcommand } from "./delete.js";
import { publishSubcommand } from "./publish.js";
import { messagesSubcommand } from "./messages.js";
import { receiveSubcommand } from "./receive.js";
import { ackSubcommand } from "./ack.js";
import { nackSubcommand } from "./nack.js";
import { dlqSubcommand } from "./dlq.js";
import { destinationsSubcommand } from "./destinations.js";
import { sourcesSubcommand } from "./sources.js";
import { consumersSubcommand } from "./consumers.js";
import { pauseSubcommand } from "./pause.js";
import { resumeSubcommand } from "./resume.js";
import { statsSubcommand } from "./stats.js";
import { getCommand } from "../../../command-prefix.js";
export const command = createCommand({
    name: 'queue',
    aliases: ['queues'],
    description: 'Manage managed message queues',
    tags: ['requires-auth'],
    examples: [
        {
            command: getCommand('cloud queue list'),
            description: 'List all queues',
        },
        {
            command: getCommand('cloud queue create worker --name my-tasks'),
            description: 'Create a worker queue',
        },
        {
            command: getCommand('cloud queue publish my-queue \'{"task":"process"}\''),
            description: 'Publish a message',
        },
        {
            command: getCommand('cloud queue receive my-queue'),
            description: 'Receive a message from a worker queue',
        },
        {
            command: getCommand('cloud queue stats'),
            description: 'View analytics for all queues',
        },
    ],
    subcommands: [
        listSubcommand,
        createSubcommand,
        getSubcommand,
        deleteSubcommand,
        publishSubcommand,
        messagesSubcommand,
        receiveSubcommand,
        ackSubcommand,
        nackSubcommand,
        dlqSubcommand,
        destinationsSubcommand,
        sourcesSubcommand,
        consumersSubcommand,
        pauseSubcommand,
        resumeSubcommand,
        statsSubcommand,
    ],
    requires: { auth: true },
});
export default command;
//# sourceMappingURL=index.js.map