import { createCommand } from "../../../../types.js";
import { getCommand } from "../../../../command-prefix.js";
import { rmSubcommand } from "./rm.js";
import { mkdirSubcommand } from "./mkdir.js";
import { rmdirSubcommand } from "./rmdir.js";
import { lsSubcommand } from "./ls.js";
import { cpSubcommand } from "./cp.js";
import { downloadSubcommand } from "./download.js";
import { uploadSubcommand } from "./upload.js";
export const command = createCommand({
    name: 'fs',
    aliases: ['files', 'file'],
    description: 'Filesystem operations for sandboxes',
    tags: ['slow', 'requires-auth'],
    examples: [
        {
            command: getCommand('cloud sandbox fs ls sbx_abc123'),
            description: 'List files in a sandbox',
        },
        {
            command: getCommand('cloud sandbox fs cp ./file.txt sbx_abc123:/path/to/file.txt'),
            description: 'Copy a file to a sandbox',
        },
    ],
    subcommands: [
        lsSubcommand,
        cpSubcommand,
        rmSubcommand,
        mkdirSubcommand,
        rmdirSubcommand,
        downloadSubcommand,
        uploadSubcommand,
    ],
    requires: { auth: true, org: true },
});
//# sourceMappingURL=index.js.map