import { createCommand } from "../../types.js";
import { accountCommand } from "./account/index.js";
import { identityCommand } from "./identity/index.js";
import { linkSubcommand } from "./link.js";
import { listSubcommand } from "./list.js";
import { statusSubcommand } from "./status.js";
import { unlinkSubcommand } from "./unlink.js";
export const gitCommand = createCommand({
    name: 'git',
    description: 'Manage GitHub integration and repository connections',
    subcommands: [
        identityCommand,
        accountCommand,
        linkSubcommand,
        listSubcommand,
        unlinkSubcommand,
        statusSubcommand,
    ],
});
//# sourceMappingURL=index.js.map