export declare function combinePromptInput(opts: {
    explicitPrompt?: string;
    stdinPrompt?: string;
    stdinMode?: 'append' | 'replace';
}): string | undefined;
export declare const completeSubcommand: import("../../../types.ts").CommandDefinition;
//# sourceMappingURL=complete.d.ts.map