import { createCommand } from "../../../types.js";
import { statsSubcommand } from "./stats.js";
const servicesCommand = createCommand({
    name: 'services',
    description: 'Service usage statistics',
    tags: ['read-only', 'requires-auth'],
    subcommands: [statsSubcommand],
});
export default servicesCommand;
//# sourceMappingURL=index.js.map