import { createCommand } from "../../../../types.js";
import { urlSubcommand } from "./url.js";
import { listSubcommand } from "./list.js";
import { deleteSubcommand } from "./delete.js";
export const destinationCommand = createCommand({
    name: 'destination',
    aliases: ['destinations', 'dest'],
    description: 'Manage email destinations for an address',
    tags: ['requires-auth'],
    requires: { auth: true },
    subcommands: [urlSubcommand, listSubcommand, deleteSubcommand],
});
//# sourceMappingURL=index.js.map