/**
 * Standard-input helpers.
 *
 * Replacement for `Bun.stdin.text()` and `Bun.stdin.stream()` using
 * Node's native `node:stream/consumers` and the runtime's web-stream
 * bridge.
 */
/**
 * Read the entire stdin stream as UTF-8 text and resolve once stdin
 * closes (i.e., the parent stops feeding input or the pipe ends).
 */
export declare function readStdinText(): Promise<string>;
/**
 * Get a Web `ReadableStream<Uint8Array>` view of stdin so the chunks
 * can be piped to a `fetch` body or our `S3ClientLike.write`.
 */
export declare function stdinWebStream(): ReadableStream<Uint8Array>;
//# sourceMappingURL=stdin.d.ts.map