import { createCommand } from "../../../types.js";
import { connectSubcommand } from "./connect.js";
import { disconnectSubcommand } from "./disconnect.js";
import { statusSubcommand } from "./status.js";
export const identityCommand = createCommand({
    name: 'identity',
    description: 'Manage your GitHub identity',
    subcommands: [connectSubcommand, disconnectSubcommand, statusSubcommand],
});
//# sourceMappingURL=index.js.map