import { createCommand } from "../../../types.js";
import { createSubcommand } from "./create.js";
import { listSubcommand } from "./list.js";
import { deleteSubcommand } from "./delete.js";
import { getSubcommand } from "./get.js";
import { logsSubcommand } from "./logs.js";
import { sqlSubcommand } from "./sql.js";
import { statsSubcommand } from "./stats.js";
import { getCommand } from "../../../command-prefix.js";
export const dbCommand = createCommand({
    name: 'db',
    aliases: ['database'],
    description: 'Manage Postgres managed database resources',
    tags: ['slow', 'requires-auth', 'requires-deployment'],
    examples: [
        { command: getCommand('cloud db list'), description: 'List all databases' },
        { command: getCommand('cloud db sql "SELECT * FROM users"'), description: 'Run SQL query' },
    ],
    subcommands: [
        createSubcommand,
        listSubcommand,
        getSubcommand,
        deleteSubcommand,
        logsSubcommand,
        sqlSubcommand,
        statsSubcommand,
    ],
});
//# sourceMappingURL=index.js.map