import { createCommand } from "../../../types.js";
import { listSubcommand } from "./list.js";
import { createSubcommand } from "./create.js";
import { getSubcommand } from "./get.js";
import { deleteSubcommand } from "./delete.js";
import { updateSubcommand } from "./update.js";
import destinationSubcommand from "./destination/index.js";
import deliverySubcommand from "./delivery/index.js";
import { statsSubcommand } from "./stats.js";
import { getCommand } from "../../../command-prefix.js";
export const command = createCommand({
    name: 'schedule',
    aliases: ['schedules', 'sched'],
    description: 'Manage scheduled tasks',
    tags: ['requires-auth'],
    requires: { auth: true },
    subcommands: [
        listSubcommand,
        createSubcommand,
        getSubcommand,
        deleteSubcommand,
        updateSubcommand,
        destinationSubcommand,
        deliverySubcommand,
        statsSubcommand,
    ],
    examples: [
        { command: getCommand('cloud schedule list'), description: 'List schedules' },
        {
            command: getCommand("cloud schedule create --name nightly --expression '0 0 * * *'"),
            description: 'Create a schedule',
        },
        {
            command: getCommand('cloud schedule get sched_abc123'),
            description: 'Get schedule details',
        },
    ],
});
export default command;
//# sourceMappingURL=index.js.map