import { type PackageManager } from '../build/detect/index.ts';
export declare const PROJECT_GENERATION = "3";
export type ProjectProvider = 'bunjs' | 'nodejs';
export interface ProjectRegistrationMetadata {
    generation: typeof PROJECT_GENERATION;
    provider?: ProjectProvider;
    framework?: string;
}
export declare function providerForPackageManager(packageManager: PackageManager): ProjectProvider;
export declare function detectProjectRegistrationMetadata(dir: string): Promise<ProjectRegistrationMetadata>;
//# sourceMappingURL=registration-metadata.d.ts.map