import type { APIClient } from '../../api.ts';
export interface LoginResult {
    apiKey: string;
    userId: string;
    expires: Date;
}
export interface SignupResult {
    apiKey: string;
    userId: string;
    expires: Date;
}
export declare function generateLoginCode(apiClient: APIClient): Promise<string>;
export declare function pollForLoginCompletion(apiClient: APIClient, code: string, timeoutMs?: number): Promise<LoginResult>;
export declare function generateSignupOTP(): string;
export declare function pollForSignupCompletion(apiClient: APIClient, otp: string, timeoutMs?: number): Promise<SignupResult>;
//# sourceMappingURL=api.d.ts.map