import { type CoderCreateWorkspaceRequest, type CoderUpdateWorkspaceRequest, type CoderWorkspaceDetail, type CoderWorkspaceSystemPromptMode } from '@agentuity/coder';
export declare const EMPTY_WORKSPACE_ERROR = "A workspace needs at least one repo, dependency, setup script, system prompt, saved skill, skill bucket, or agent";
export declare const SetupScriptValidationError: {
    new (args?: ({
        message: string;
        path?: string;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("@agentuity/core").RichError & {
        readonly _tag: "SetupScriptValidationError";
    } & Readonly<{
        message: string;
        path?: string;
    }>;
    readonly defaultMessage?: string;
};
export declare const SystemPromptValidationError: {
    new (args?: ({
        message: string;
        path?: string;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("@agentuity/core").RichError & {
        readonly _tag: "SystemPromptValidationError";
    } & Readonly<{
        message: string;
        path?: string;
    }>;
    readonly defaultMessage?: string;
};
export declare function normalizeSystemPromptMode(value?: string): CoderWorkspaceSystemPromptMode | undefined;
export declare function parseCommaList(value?: string): string[];
export declare function readSetupScript(input: {
    setupScript?: string;
    setupScriptFile?: string;
}): Promise<string | undefined>;
export declare function readSystemPrompt(input: {
    systemPrompt?: string;
    systemPromptFile?: string;
}): Promise<string | undefined>;
export declare function hasWorkspaceSelections(input: CoderCreateWorkspaceRequest): boolean;
export declare function hasWorkspaceUpdate(input: CoderUpdateWorkspaceRequest): boolean;
export declare function formatWorkspaceValidationMessage(issues: Array<{
    message: string;
}>): string;
export declare function printWorkspaceSummary(workspace: CoderWorkspaceDetail): void;
//# sourceMappingURL=common.d.ts.map