import { createCommand } from "../../../types.js";
import { createSubcommand } from "./create.js";
import { listSubcommand } from "./list.js";
import { getSubcommand } from "./get.js";
import { deleteSubcommand } from "./delete.js";
import { destinationCommand } from "./destination/index.js";
import { sendSubcommand } from "./send.js";
import { inboundCommand } from "./inbound/index.js";
import { outboundCommand } from "./outbound/index.js";
import { statsSubcommand } from "./stats.js";
export const emailCommand = createCommand({
    name: 'email',
    aliases: ['mail'],
    description: 'Manage email addresses and messages',
    tags: ['requires-auth'],
    subcommands: [
        createSubcommand,
        listSubcommand,
        getSubcommand,
        deleteSubcommand,
        destinationCommand,
        sendSubcommand,
        inboundCommand,
        outboundCommand,
        statsSubcommand,
    ],
    requires: { auth: true },
});
//# sourceMappingURL=index.js.map