import { createCommand } from "../../../types.js";
import { getSubcommand } from "./get.js";
import { listSubcommand } from "./list.js";
import { deleteSubcommand } from "./delete.js";
import { getCommand } from "../../../command-prefix.js";
export const threadCommand = createCommand({
    name: 'thread',
    aliases: ['threads'],
    description: 'Manage threads',
    tags: ['requires-auth'],
    examples: [
        { command: getCommand('cloud thread list'), description: 'List all threads' },
        { command: getCommand('cloud thread get <id>'), description: 'Get thread details' },
        { command: getCommand('cloud thread delete <id>'), description: 'Delete a thread' },
    ],
    subcommands: [getSubcommand, listSubcommand, deleteSubcommand],
});
//# sourceMappingURL=index.js.map