import type { Logger } from '@agentuity/core';
import { type RegionList } from '@agentuity/server';
import type { APIClient } from './api.ts';
/**
 * Fetch regions from API with caching
 */
export declare function fetchRegionsWithCache(profileName: string, apiClient: APIClient, logger: Logger): Promise<RegionList>;
//# sourceMappingURL=regions.d.ts.map