import { createCommand } from "../../../types.js";
import { getSubcommand } from "./get.js";
import { listSubcommand } from "./list.js";
import { logsSubcommand } from "./logs.js";
import { getCommand } from "../../../command-prefix.js";
export const sessionCommand = createCommand({
    name: 'session',
    aliases: ['sessions'],
    description: 'Manage sessions',
    tags: ['requires-auth'],
    examples: [
        { command: getCommand('cloud session list'), description: 'List all sessions' },
        { command: getCommand('cloud session logs <id>'), description: 'View session logs' },
    ],
    subcommands: [getSubcommand, listSubcommand, logsSubcommand],
});
//# sourceMappingURL=index.js.map