import type { CommandDefinition, Config, Logger, SubcommandDefinition } from './types.ts';
/**
 * Check for updates and optionally prompt to upgrade
 * Should be called early in the CLI initialization, before commands execute
 */
export declare function checkForUpdates(config: Config | null, logger: Logger, options: {
    json?: boolean;
    quiet?: boolean;
    validate?: boolean;
    dryRun?: boolean;
    skipVersionCheck?: boolean;
    interactive?: boolean;
}, commandDef: CommandDefinition | undefined, subcommandDef: SubcommandDefinition | undefined, args: string[]): Promise<void>;
//# sourceMappingURL=version-check.d.ts.map