import { ScheduleService } from '@agentuity/schedule';
import type { Logger } from '@agentuity/core';
import type { AuthData, Config, GlobalOptions } from '../../../types.ts';
export interface ScheduleContext {
    logger: Logger;
    auth: AuthData;
    config: Config | null;
    options: GlobalOptions;
}
export declare function createScheduleAdapter(ctx: ScheduleContext): Promise<ScheduleService>;
//# sourceMappingURL=util.d.ts.map