import { createCommand } from "../../types.js";
import { apikeyCommand } from "./apikey.js";
import { loginCommand } from "./login.js";
import { logoutCommand } from "./logout.js";
import { signupCommand } from "./signup.js";
import { whoamiCommand } from "./whoami.js";
import { sshSubcommand } from "./ssh/index.js";
import { orgSubcommand } from "./org/index.js";
import { getCommand } from "../../command-prefix.js";
export const command = createCommand({
    name: 'auth',
    description: 'Authentication and authorization related commands',
    tags: ['read-only', 'fast'],
    examples: [
        { command: getCommand('auth login'), description: 'Login to your account' },
        { command: getCommand('auth whoami'), description: 'Show current user info' },
        { command: getCommand('auth org select'), description: 'Set default organization' },
    ],
    subcommands: [
        apikeyCommand,
        loginCommand,
        logoutCommand,
        signupCommand,
        whoamiCommand,
        sshSubcommand,
        orgSubcommand,
    ],
});
//# sourceMappingURL=index.js.map