import { createCommand } from "../../../types.js";
import { llmSubcommand } from "./llm.js";
import { getCommand } from "../../../command-prefix.js";
export const promptCommand = createCommand({
    name: 'prompt',
    description: 'Generate prompts for LLMs',
    tags: ['read-only', 'fast'],
    examples: [
        { command: getCommand('ai prompt llm'), description: 'Generate LLM-specific prompt' },
    ],
    subcommands: [llmSubcommand],
});
export default promptCommand;
//# sourceMappingURL=index.js.map