import { createCommand } from "../../../../types.js";
import { listSubcommand } from "./list.js";
import { getSubcommand } from "./get.js";
export const inboundCommand = createCommand({
    name: 'inbound',
    description: 'Manage inbound (received) emails',
    tags: ['requires-auth'],
    requires: { auth: true },
    subcommands: [listSubcommand, getSubcommand],
});
//# sourceMappingURL=index.js.map