/**
 * Agent Onboarding Prompt
 *
 * This generates the markdown prompt that coding agents use to guide developers
 * through Agentuity setup after the CLI has been installed.
 */
export declare function getAgentPromptMarkdown(): string;
//# sourceMappingURL=agentPrompt.d.ts.map