import { createCommand } from "../../../../types.js";
import { listSubcommand } from "./list.js";
import { getCommand } from "../../../../command-prefix.js";
export const runtimeCommand = createCommand({
    name: 'runtime',
    aliases: ['rt', 'runtimes'],
    description: 'Manage sandbox runtimes',
    tags: ['slow', 'requires-auth'],
    examples: [
        {
            command: getCommand('cloud sandbox runtime list'),
            description: 'List all available runtimes',
        },
    ],
    subcommands: [listSubcommand],
    requires: { auth: true, org: true },
});
//# sourceMappingURL=index.js.map