import type { Logger } from '@agentuity/core';
import type { APIClient } from '../../../api.ts';
import type { Config } from '../../../types.ts';
export interface RunGitAccountAddOptions {
    apiClient: APIClient;
    logger: Logger;
    config?: Config | null;
}
export interface RunGitAccountAddResult {
    added: boolean;
    cancelled?: boolean;
}
export declare function runGitAccountAdd(options: RunGitAccountAddOptions): Promise<RunGitAccountAddResult>;
export declare const addSubcommand: import("../../../types.ts").SubcommandDefinition;
//# sourceMappingURL=add.d.ts.map