import type { Logger } from '@agentuity/core';
export interface StreamUrlOptions {
    signal?: AbortSignal;
    follow?: boolean;
    timestamps?: boolean;
    grep?: string;
    tail?: number;
    json?: boolean;
    label?: string;
    raw?: boolean;
    v2?: boolean;
}
export interface StreamUrlResult {
    bytesRead: number;
    chunks: number;
}
export declare class StreamFetchError extends Error {
    status: number;
    statusText: string;
    constructor(status: number, statusText: string, message: string);
}
export declare function streamUrlToWritable(url: string, writable: NodeJS.WritableStream, logger: Logger, options?: StreamUrlOptions): Promise<StreamUrlResult>;
//# sourceMappingURL=stream-url.d.ts.map