export interface Capability {
    id: string;
    name: string;
    description: string;
    commands: string[];
    requiresAuth?: boolean;
    requiresProject?: boolean;
}
export interface CapabilitiesResponse {
    version: string;
    capabilities: Capability[];
    workflows: Array<{
        name: string;
        description: string;
        steps: string[];
    }>;
}
export declare const showSubcommand: import("../../../types.ts").SubcommandDefinition;
//# sourceMappingURL=show.d.ts.map