/**
 * TSC Output Parser
 *
 * Parses TypeScript compiler output into structured JSON format.
 *
 * This is an internalized version of @aivenio/tsc-output-parser.
 * Original source: https://github.com/Aiven-Open/tsc-output-parser
 *
 * Copyright Aiven
 * Licensed under the Apache License, Version 2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Generated by PEG.js v. 0.10.0 (ts-pegjs plugin v. 0.2.7)
 * https://pegjs.org/   https://github.com/metadevpro/ts-pegjs
 *
 * NOTE: This file is auto-generated. Do not edit manually.
 * TypeScript and ESLint checks are disabled for this file.
 */
export interface GrammarPath {
    type: 'Path';
    value: string;
}
export interface GrammarCursor {
    type: 'Cursor';
    value: {
        line: number;
        col: number;
    };
}
export interface GrammarTsError {
    type: 'TsError';
    value: {
        type: 'error' | 'warning';
        errorString: string;
    };
}
export interface GrammarMessage {
    type: 'Message';
    value: string;
}
export interface GrammarItem {
    type: 'Item';
    value: {
        path: GrammarPath;
        cursor: GrammarCursor;
        tsError: GrammarTsError;
        message: GrammarMessage;
    };
}
interface IParseOptions {
    startRule?: string;
    [key: string]: unknown;
}
export type ParseFunction = (input: string, options?: IParseOptions) => GrammarItem[];
export declare const parse: ParseFunction;
export {};
//# sourceMappingURL=tsc-output-parser.d.ts.map