import { createCommand } from "../../types.js";
import { createCommand as createProfileCmd } from "./create.js";
import { useCommand } from "./use.js";
import { listCommand } from "./list.js";
import { showCommand } from "./show.js";
import { deleteCommand } from "./delete.js";
import { currentCommand } from "./current.js";
import { getCommand } from "../../command-prefix.js";
export const command = createCommand({
    name: 'profile',
    description: 'Manage configuration profiles',
    tags: ['read-only', 'fast'],
    hidden: true,
    examples: [
        { command: getCommand('profile list'), description: 'List all profiles' },
        {
            command: getCommand('profile use production'),
            description: 'Switch to production profile',
        },
    ],
    subcommands: [
        createProfileCmd,
        useCommand,
        listCommand,
        showCommand,
        deleteCommand,
        currentCommand,
    ],
});
//# sourceMappingURL=index.js.map