/**
 * Abbreviate a string to a maximum length, adding ellipsis if truncated
 */
export declare function abbreviate(str: string | null | undefined, maxLength?: number): string;
/**
 * Abbreviate a description (longer default length)
 */
export declare function abbreviateDescription(str: string | null | undefined, maxLength?: number): string;
//# sourceMappingURL=format.d.ts.map