import { TaskStorageService } from '@agentuity/task';
import type { Logger } from '@agentuity/core';
import type { AuthData, Config, GlobalOptions } from '../../../types.ts';
export interface TaskContext {
    logger: Logger;
    auth: AuthData;
    config: Config | null;
    options: GlobalOptions;
    project?: {
        projectId: string;
        orgId: string;
    };
}
export declare function createStorageAdapter(ctx: TaskContext): Promise<TaskStorageService>;
export declare function createStorageAdapterOptionalOrg(ctx: TaskContext): Promise<TaskStorageService>;
export declare function cacheTaskId(ctx: {
    config: Config | null;
    options: GlobalOptions;
    project?: {
        orgId: string;
    };
}, taskId: string): Promise<void>;
export declare function parseMetadataFlag(raw: string | undefined): Record<string, unknown> | undefined;
export declare function parseDuration(duration: string): number;
export declare function truncate(s: string, max: number): string;
export declare function resolveMeId(id: string | undefined, ctx: TaskContext): string | undefined;
//# sourceMappingURL=util.d.ts.map