import { createCommand } from "../../../types.js";
import { createSubcommand } from "./create.js";
import { listSubcommand } from "./list.js";
import { getSubcommand } from "./get.js";
import { deleteSubcommand } from "./delete.js";
import { getCommand } from "../../../command-prefix.js";
export const command = createCommand({
    name: 'apikey',
    aliases: ['apikeys'],
    description: 'Manage API keys',
    tags: ['fast', 'requires-auth'],
    examples: [
        { command: getCommand('cloud apikey list'), description: 'List all API keys' },
        {
            command: getCommand('cloud apikey create --name "My Key" --expires-at 1y'),
            description: 'Create new API key',
        },
    ],
    subcommands: [createSubcommand, listSubcommand, getSubcommand, deleteSubcommand],
});
export default command;
//# sourceMappingURL=index.js.map