import { createCommand } from "../../../types.js";
import { listSubcommand } from "./list.js";
import { createWorkspaceSubcommand } from "./create.js";
import { getWorkspaceSubcommand } from "./get.js";
import { deleteWorkspaceSubcommand } from "./delete.js";
import { getCommand } from "../../../command-prefix.js";
export const workspaceCommand = createCommand({
    name: 'workspace',
    aliases: ['workspaces', 'ws'],
    description: 'Manage Coder workspaces',
    tags: ['requires-auth'],
    requires: { auth: true, org: true },
    examples: [
        {
            command: getCommand('coder workspace list'),
            description: 'List all workspaces',
        },
        {
            command: getCommand('coder workspace create "My Workspace" --repo https://github.com/org/repo'),
            description: 'Create a new workspace',
        },
        {
            command: getCommand('coder workspace get ws_abc123'),
            description: 'Show workspace details',
        },
        {
            command: getCommand('coder workspace delete ws_abc123'),
            description: 'Delete a workspace',
        },
    ],
    subcommands: [
        listSubcommand,
        createWorkspaceSubcommand,
        getWorkspaceSubcommand,
        deleteWorkspaceSubcommand,
    ],
});
//# sourceMappingURL=index.js.map