import { createCommand } from "../../types.js";
import { deploySubcommand } from "./deploy.js";
import { dbCommand } from "./db/index.js";
import { redisCommand } from "./redis/index.js";
import { storageCommand } from "./storage/index.js";
import { sessionCommand } from "./session/index.js";
import { threadCommand } from "./thread/index.js";
import { sshSubcommand } from "./ssh.js";
import { scpSubcommand } from "./scp/index.js";
import { deploymentCommand } from "./deployment/index.js";
import keyvalueCommand from "./keyvalue/index.js";
import queueCommand from "./queue/index.js";
import webhookCommand from "./webhook/index.js";
import { agentCommand } from "./agent/index.js";
import envCommand from "./env/index.js";
import apikeyCommand from "./apikey/index.js";
import { aigatewayCommand } from "./aigateway/index.js";
import oidcCommand from "./oidc/index.js";
import streamCommand from "./stream/index.js";
import vectorCommand from "./vector/index.js";
import { emailCommand } from "./email/index.js";
import taskCommand from "./task/index.js";
import sandboxCommand from "./sandbox/index.js";
import scheduleCommand from "./schedule/index.js";
import workflowCommand from "./workflow/index.js";
import servicesCommand from "./services/index.js";
import { regionSubcommand } from "./region/index.js";
import { machineCommand } from "./machine/index.js";
import { monitorSubcommand } from "./monitor.js";
import { getCommand } from "../../command-prefix.js";
export const command = createCommand({
    name: 'cloud',
    description: 'Cloud related commands',
    tags: ['slow', 'requires-auth'],
    examples: [
        { command: getCommand('cloud deploy'), description: 'Deploy your agent to the cloud' },
        { command: getCommand('cloud deployment list'), description: 'List all deployments' },
        { command: getCommand('cloud region select'), description: 'Set default region' },
    ],
    subcommands: [
        aigatewayCommand,
        apikeyCommand,
        oidcCommand,
        keyvalueCommand,
        queueCommand,
        webhookCommand,
        taskCommand,
        agentCommand,
        streamCommand,
        emailCommand,
        vectorCommand,
        sandboxCommand,
        scheduleCommand,
        workflowCommand,
        envCommand,
        deploySubcommand,
        dbCommand,
        redisCommand,
        storageCommand,
        servicesCommand,
        sessionCommand,
        threadCommand,
        sshSubcommand,
        scpSubcommand,
        monitorSubcommand,
        deploymentCommand,
        regionSubcommand,
        machineCommand,
    ],
});
//# sourceMappingURL=index.js.map