import { getInstallationType, type InstallationType } from '../../utils/installation-type.ts';
/**
 * Get the installation type - re-exported for backward compatibility
 * @deprecated Use getInstallationType() from '../../utils/installation-type' instead
 */
export { getInstallationType, type InstallationType };
/**
 * Check if running from a global installation
 * This replaces the old isRunningFromExecutable() function
 */
export declare function isGlobalInstall(): boolean;
/**
 * Fetch the latest version from the API
 * @internal Exported for testing
 */
export declare function fetchLatestVersion(): Promise<string>;
export declare const command: import("../../types.ts").CommandDefinition;
//# sourceMappingURL=index.d.ts.map