import { createCommand } from "../../../types.js";
import { listSubcommand } from "./list.js";
import { getSubcommand } from "./get.js";
import { getCommand } from "../../../command-prefix.js";
export const command = createCommand({
    name: 'workflow',
    aliases: ['workflows', 'wf'],
    description: 'Manage workflows',
    tags: ['requires-auth'],
    requires: { auth: true },
    subcommands: [listSubcommand, getSubcommand],
    examples: [
        { command: getCommand('cloud workflow list'), description: 'List workflows' },
        {
            command: getCommand('cloud workflow get wf_abc123'),
            description: 'Get workflow details',
        },
    ],
});
export default command;
//# sourceMappingURL=index.js.map