import { createCommand } from "../../../types.js";
import { configSubcommand } from "./config.js";
import { createSubcommand } from "./create.js";
import { listSubcommand } from "./list.js";
import { deleteSubcommand } from "./delete.js";
import { getSubcommand } from "./get.js";
import { uploadSubcommand } from "./upload.js";
import { downloadSubcommand } from "./download.js";
import { getCommand } from "../../../command-prefix.js";
export const storageCommand = createCommand({
    name: 'storage',
    aliases: ['s3'],
    description: 'Manage S3 compatible managed storage resources',
    tags: ['slow', 'requires-auth', 'requires-deployment'],
    examples: [
        { command: getCommand('cloud storage list'), description: 'List all storage resources' },
        {
            command: getCommand('cloud storage upload ./file.txt'),
            description: 'Upload file to storage',
        },
    ],
    subcommands: [
        configSubcommand,
        createSubcommand,
        listSubcommand,
        getSubcommand,
        uploadSubcommand,
        downloadSubcommand,
        deleteSubcommand,
    ],
});
//# sourceMappingURL=index.js.map