import { createCommand } from "../../../types.js";
import { runSubcommand } from "./run.js";
import { createSubcommand } from "./create.js";
import { execSubcommand } from "./exec.js";
import { listSubcommand } from "./list.js";
import { getSubcommand } from "./get.js";
import { deleteSubcommand } from "./delete.js";
import { snapshotCommand } from "./snapshot/index.js";
import { runtimeCommand } from "./runtime/index.js";
import { command as fsCommand } from "./fs/index.js";
import { command as executionCommand } from "./execution/index.js";
import { command as jobCommand } from "./job/index.js";
import { envSubcommand } from "./env.js";
import { pauseSubcommand } from "./pause.js";
import { resumeSubcommand } from "./resume.js";
import { checkpointCommand } from "./checkpoint/index.js";
import { statsSubcommand } from "./stats.js";
import { eventsSubcommand } from "./events.js";
import { getCommand } from "../../../command-prefix.js";
export const command = createCommand({
    name: 'sandbox',
    aliases: ['sb'],
    description: 'Manage sandboxes for managed isolated code execution',
    tags: ['slow', 'requires-auth'],
    examples: [
        {
            command: getCommand('cloud sandbox run -- echo "hello"'),
            description: 'Run a one-shot command in a sandbox',
        },
        {
            command: getCommand('cloud sandbox create'),
            description: 'Create an interactive sandbox',
        },
        {
            command: getCommand('cloud sandbox list'),
            description: 'List all sandboxes',
        },
    ],
    subcommands: [
        runSubcommand,
        createSubcommand,
        execSubcommand,
        listSubcommand,
        getSubcommand,
        deleteSubcommand,
        snapshotCommand,
        runtimeCommand,
        fsCommand,
        executionCommand,
        jobCommand,
        envSubcommand,
        pauseSubcommand,
        resumeSubcommand,
        checkpointCommand,
        statsSubcommand,
        eventsSubcommand,
    ],
    requires: { auth: true, org: true },
});
export default command;
//# sourceMappingURL=index.js.map